
# Slot: treats


holds between a therapeutic procedure or chemical substance and a disease or phenotypic feature that it is used to treat

URI: [biolink:treats](https://w3id.org/biolink/vocab/treats)

## Domain and Range

[Treatment](Treatment.md) ->  <sub>1..*</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [affects](affects.md)

## Children


## Used by

 * [Treatment](Treatment.md)
